==> org.eclipse.ocl.examples.debug.source_1.0.0.v20140601-1121.jar: org/eclipse/ocl/examples/debug/stepper/OCLStepperVisitor.java <==
/*******************************************************************************
 * Copyright (c) 2014 E.D.Willink and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   E.D.Willink - Initial API and implementation
 *******************************************************************************/
package org.eclipse.ocl.examples.debug.stepper;

import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.ocl.examples.debug.vm.evaluator.IStepper;
import org.eclipse.ocl.examples.debug.vm.evaluator.IStepperVisitor;
import org.eclipse.ocl.examples.domain.utilities.DomainUtil;
import org.eclipse.ocl.examples.pivot.Element;
import org.eclipse.ocl.examples.pivot.ExpressionInOCL;
import org.eclipse.ocl.examples.pivot.IfExp;
import org.eclipse.ocl.examples.pivot.IterateExp;
import org.eclipse.ocl.examples.pivot.IteratorExp;
import org.eclipse.ocl.examples.pivot.LetExp;
import org.eclipse.ocl.examples.pivot.OCLExpression;
import org.eclipse.ocl.examples.pivot.OperationCallExp;
import org.eclipse.ocl.examples.pivot.PropertyCallExp;
import org.eclipse.ocl.examples.pivot.Variable;
import org.eclipse.ocl.examples.pivot.util.AbstractExtendingVisitor;
import org.eclipse.ocl.examples.pivot.util.Visitable;

public class OCLStepperVisitor extends AbstractExtendingVisitor<IStepper, Object> implements IStepperVisitor
{
	public static @NonNull OCLStepperVisitor INSTANCE = new OCLStepperVisitor(OCLStepperVisitor.class);
	
	protected OCLStepperVisitor(@NonNull Object context) {
		super(context);
	}

	@Override
	public @NonNull IStepper getStepper(@NonNull Element object) {
		return DomainUtil.nonNullState(object.accept(this));
	}

	@Override
	public @Nullable IStepper visitElement(@NonNull Element object) {
		return NonStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitExpressionInOCL(@NonNull ExpressionInOCL object) {
		return ExpressionInOCLStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitIfExp(@NonNull IfExp object) {
		return IfExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitIterateExp(@NonNull IterateExp object) {
		return IterateExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitIteratorExp(@NonNull IteratorExp object) {
		return LoopExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitLetExp(@NonNull LetExp object) {
		return LetExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitOCLExpression(@NonNull OCLExpression object) {
		return PostStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitOperationCallExp(@NonNull OperationCallExp object) {
		return OperationCallExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitPropertyCallExp(@NonNull PropertyCallExp object) {
		return PropertyCallExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitVariable(@NonNull Variable object) {
		return VariableStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visiting(@NonNull Visitable visitable) {
		throw new IllegalArgumentException("Unsupported " + visitable.eClass().getName() + " for OCLStepperVisitor");
	}
}

==> org.eclipse.ocl.examples.debug.source_2.3.0.v20170522-1753.jar: org/eclipse/ocl/examples/debug/stepper/OCLStepperVisitor.java <==
/*******************************************************************************
 * Copyright (c) 2014, 2016 Willink Transformations and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   E.D.Willink - Initial API and implementation
 *******************************************************************************/
package org.eclipse.ocl.examples.debug.stepper;

import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.ocl.examples.debug.vm.evaluator.IStepper;
import org.eclipse.ocl.examples.debug.vm.evaluator.IStepperVisitor;
import org.eclipse.ocl.pivot.Element;
import org.eclipse.ocl.pivot.ExpressionInOCL;
import org.eclipse.ocl.pivot.IfExp;
import org.eclipse.ocl.pivot.IterateExp;
import org.eclipse.ocl.pivot.IteratorExp;
import org.eclipse.ocl.pivot.LetExp;
import org.eclipse.ocl.pivot.OCLExpression;
import org.eclipse.ocl.pivot.OperationCallExp;
import org.eclipse.ocl.pivot.PropertyCallExp;
import org.eclipse.ocl.pivot.Variable;
import org.eclipse.ocl.pivot.util.AbstractExtendingVisitor;
import org.eclipse.ocl.pivot.util.Visitable;
import org.eclipse.ocl.pivot.utilities.ClassUtil;

public class OCLStepperVisitor extends AbstractExtendingVisitor<@Nullable IStepper, @NonNull Object> implements IStepperVisitor
{
	public static @NonNull OCLStepperVisitor INSTANCE = new OCLStepperVisitor(OCLStepperVisitor.class);
	
	protected OCLStepperVisitor(@NonNull Object context) {
		super(context);
	}

	@Override
	public @NonNull IStepper getStepper(@NonNull Element object) {
		return ClassUtil.nonNullState(object.accept(this));
	}

	@Override
	public @Nullable IStepper visitElement(@NonNull Element object) {
		return NonStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitExpressionInOCL(@NonNull ExpressionInOCL object) {
		return ExpressionInOCLStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitIfExp(@NonNull IfExp object) {
		return IfExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitIterateExp(@NonNull IterateExp object) {
		return IterateExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitIteratorExp(@NonNull IteratorExp object) {
		return LoopExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitLetExp(@NonNull LetExp object) {
		return LetExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitOCLExpression(@NonNull OCLExpression object) {
		return PostStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitOperationCallExp(@NonNull OperationCallExp object) {
		return OperationCallExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitPropertyCallExp(@NonNull PropertyCallExp object) {
		return PropertyCallExpStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visitVariable(@NonNull Variable object) {
		return VariableStepper.INSTANCE;
	}

	@Override
	public @Nullable IStepper visiting(@NonNull Visitable visitable) {
		throw new IllegalArgumentException("Unsupported " + visitable.eClass().getName() + " for OCLStepperVisitor");
	}
}
